Learn R Programming

ExomeDepth (version 0.9.2)

Conrad.hg19.common.CNVs: Conrad et al common CNVs

Description

Positions of common CNV calls (detected in a panel of 42 sample) from the Conrad et al paper (Nature 2010). This is build hg19 of the human genome.

Usage

data(Conrad.hg19)

Arguments

format

A data frame with common CNV calls.

source

Conrad et al, Origins and functional impact of copy number variation in the human genome, Nature 2010