Learn R Programming

ExomeDepth (version 0.9.2)

get.power.betabinom: Estimate the power to compare two beta-binomial distributions.

Description

A power study useful in the context of ExomeDepth.

Usage

get.power.betabinom(size,
my.phi,
my.p,
my.alt.p,
theory = FALSE,
frequentist = FALSE,
limit = FALSE)

Arguments

size
Number of samples from the beta-binomial distribution.
my.phi
Over-dispersion parameter.
my.p
Expected p under the null.
my.alt.p
Expected p under the alternative.
theory
logical, should a theoretical limit (large sample size) be used? Defaults to FALSE.
frequentist
logical, should a frequentist version be used? Defaults to FALSE.
limit
logical, should another large sample size limit be used? Defaults to FALSE.

Value

  • An expected Bayes factor.