Learn R Programming

ExomeDepth (version 0.9.2)

qbetabinom: Quantile for betabin function

Description

Quantile function for the betabinomal distribution using the p/phi parameterisation.

Usage

qbetabinom(p, size, phi, prob)

Arguments

p
Point of the distribution from which one is looking for the quantile
size
Sample size of the random variable
phi
Over-dispersion parameter
prob
Mean probability of the binomial distribution

Value

  • A real number corresponding to the quantile p.

Details

Filling a gap in the VGAM package.

See Also

VGAM R package.