Rdocumentation
powered by
Learn R Programming
ExomeDepth (version 1.0.7)
viterbi.hmm: Computes the Viterbi path for a hidden markov model
Description
Estimates the most likely path for a hidden Markov Chain using the maximum likelihood Viterbi algorithm.
Usage
viterbi.hmm(transitions, loglikelihood, positions, expected.CNV.length)
Arguments
transitions
Transition matrix
loglikelihood
numeric matrix containing the loglikelihood of the data under the possible states
positions
Positions of the exons
expected.CNV.length
Expected length of CNV calls, which has an impact on the transition matrix between CNV states.
Value
comp1
Description of 'comp1'
comp2
Description of 'comp2'
Details
Standard forward-backward Viterbi algorithm using a precomputed matrix of likelihoods.